from voicex import TTS, Voices

#Specify the IP of the server where the TTS backend is running
server_ip = "xxx.xxx.xx.xx"

#Specify your voicex file, and the ip and port of the server where your voicex instance is running.
tts = TTS(voice="path-to-your-own-voice-file.voicex", server=server_ip)

#Alternatively, you can use one of the predefined voices
tts = TTS(voice=Voices.SILVAN, server=server_ip)

#Synthesize, speak or write stuff.
text = "This is a test sentence. I hope you like my voice."
tts.speak(text)
wav_data, sample_rate = tts.synthesize(text)
tts.write(text, "output.wav")


import requests
from io import BytesIO
import numpy as np
from scipy.io.wavfile import write
import sounddevice as sd
import pickle
import webbrowser
import sys
import enum


class TTS():
    def __init__(self, voice=None, server=None, port="5000", ssl=False):
        if server is None:
            sys.exit("VoiceX: You have to specify the TTS server IP/URL!!!")

        self.server = server
        self.port = port
        if not ssl:
            protocol = "http://"
        else:
            protocol = "https://"
        self.base_url = protocol + self.server + ":" + self.port
        self.endpoint = self.base_url + "/api"
        if voice is None:
            self.open_web_interface()
        else:
            if isinstance(voice, enum.Enum):
                voice_path = voice.value
            else:
                voice_path = voice
            with open(voice_path, 'rb') as inp:
                self.voice = dict(enumerate(pickle.load(inp)))
    def synthesize(self, text):
        json_dict = self.voice
        json_dict["text"] = text
        res = requests.post(self.endpoint, json=json_dict)
        pass
        if res.ok:
            response_bytes = BytesIO(res.content)
            header = response_bytes.read(44)  # Assuming a standard WAV header size of 44 bytes
            sample_rate = int.from_bytes(header[24:28], byteorder='little')
            wav_data = np.frombuffer(response_bytes.read(), dtype=np.int16)
            return wav_data, sample_rate
        else:
            print("Something went wrong with the TTS API call.")
            return None, None

    def speak(self, text):
        wav_data, sample_rate = self.synthesize(text)
        sd.play(wav_data, sample_rate)
        sd.wait()

    def write(self, text, filename):
        wav_data, sample_rate = self.synthesize(text)
        write(filename, sample_rate, wav_data)

    def open_web_interface(self):
        webbrowser.open(self.base_url)
        sys.exit("VoiceX: Build a voice file.")


from enum import Enum

class Voices(Enum):
    SILVAN = "voices/silvan.voicex"
    GABBY = "voices/gabby.voicex"
    GRANNY = "voices/granny.voicex"
    KIMBERLY = "voices/kimberly.voicex"
    ELISABETH = "voices/drw_female_1.voicex"
    LISA = "voices/lisa_old.voicex"
    DRW_FEMALE_1 = "voices/drw_female_1.voicex"
    DRW_FEMALE_2 = "voices/drw_female_2.voicex"
    DRW_FEMALE_3 = "voices/drw_female_3.voicex"
    MALE_DEPRESSED = "voices/male_depressed.voicex"
    MALE_SHY_1 = "voices/male_shy_1.voicex"
    MALE_SHY_2 = "voices/male_shy_2.voicex"
    LENNY = "voices/lenny.voicex"
    ANDREA = "voices/andrea.voicex"



from voicex import TTS, Voices
import json
import pickle
import numpy as np
#Specify the IP of the server where the TTS backend is running
server_ip = "137.250.24.59"

#Specify your voicex file, and the ip and port of the server where your voicex instance is running.
#tts = TTS(voice="path-to-your-own-voice-file.voicex", server=server_ip)

#Alternatively, you can use one of the predefined voices

#
# #Synthesize, speak or write stuff.
# text = "Here is how the evolutionary algorithm inside voice x works."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output1.wav")
#
# text = "The evolutionary algorithm searches through the speaker embeddings of the TTS model."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output2.wav")
#
# text = "It starts with two completely random speaker embeddings."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output3.wav")
#
# text = "Those embeddings are synthesized to speech."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output4.wav")
#
# text = "The resulting speech files are presented to the user through the voice x interface."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output5.wav")
#
# text = "The user simply selects the 'better' one? Whatever better might be."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output6.wav")
#
# text = "That better embedding gets algorithmically mutated."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output7.wav")
#
# text = "That means, gaussian noise is added to the embedding to slightly alter it."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output8.wav")
#
# text = "Only the better embedding, and the mutated one, are kept."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output9.wav")
#
# text = "The worse embedding is thrown away."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output10.wav")
#
# text = "Now that we have to new embeddings, we start again from the top."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output11.wav")
#
# text = "We are doing this loop, over and over again."
# tts.speak(text)
# wav_data, sample_rate = tts.synthesize(text)
# tts.write(text, "output12.wav")
f1 = open('female.voicex','rb')
t1 = pickle.load(f1)
f2 = open('voices/andrea_converted.voicex', 'rb')
t2 = pickle.load(f2)

tts = TTS(voice=Voices.LENNY, server=server_ip)
# tts = TTS(voice="andrea_converted.voicex", server=server_ip)
text = "A leaf cuts and trimms any wood"





tts = TTS(voice="andrea_converted.voicex", server=server_ip)
tts.speak(text)
wav_data, sample_rate = tts.synthesize(text)
tts.write(text, "lenny_test.wav")


import json
import pickle
import numpy as np

input_json = 'andrea_14.json'
output_voicex_file = 'voices/andrea_converted.voicex'


f = open(input_json)
test_json = json.load(f)

voicex_converted = []
voicex_converted.append(test_json["voice1"])
voicex_converted.append(test_json["voice2"])
voicex_converted.append(test_json["voice3"])
voicex_converted.append(test_json["voice4"])
voicex_converted.append(test_json["voice5"])
voicex_converted.append(0)
voicex_converted.append(0)
voicex_converted.append(0)
voicex_converted.append(0)
voicex_converted.append(0)
with open(output_voicex_file, 'wb') as outp:
    pickle.dump(np.array(voicex_converted), outp)